See fitParaIND, fitParaAR1 for details of the model explanations.
rNBME.R(
gdist = "G", n = 200, sn = 5, th = exp(1.3),
u1 = rep(1.5, 5), u2 = rep(1.5, 5),
a = exp(-0.5),d=NULL, othrp = list(u.n = 3, s.n = 0.5, p.mx = 0.05, sh.mx = NA)
)The distribution of the random effect term $G[i]$.
If gdist="G", $G[i]$ is from the gamma distribution.
If gdist="N", $G[i]$ is from the log normal distribution.
If gdist="U", $G[i]$ (on the log scale) is from the uniform distribution.
If gdist="GN", $G[i]$ is from the mixture of the gamma distribution and the normal distribution.
If the generated values are negative, they are truncated to zero.
If gdist="NoN", $G[i]$ is sampled from the pre-specified vector othrp with replacement.
gdist="G", th is a scale parameter of the gamma distribution.If gdist="N" or gdist=="U", th is $Var(G[i])$.
If gdist="GN", see details.
If gdist="NoN", this parameter is not used.
A vector of length sn, specifying the mean of the treatment group 1 $E(Y[ij])$ = u1[j].
u2[j].
The dispersion parameter $\alpha$ of the negative binomial mixed-effect independent model. See description in lmeNB.
d=NULL, generate data from the independent model.
If d is a scalar between 0 and 1, then d is $delta$ in the AR(1) model, and generate datasets from the AR(1) model.
gdist="GN", parameters for the GN option. See details.
If gdist="NoN", othrp is a vector, containing a sample of $G[i]$, which is treated as a population and $G[i]$ is resampled.
n*sn containing patient IDs: rep(1:n,each=sn)n*sn containing the indicies of time points: rep(1:sn, n)n*sn containing the indicies of the treatment groupsn*sn containing generated response countsn*sn containing generated random effect termsThe generated datasets have equal number of scans per person.
The number of patients in the two groups are the same.
If gdist=="GN", datasets are generated from:
othrp$p.mx*N(mean=othrp$u.n,s.d=othrp$s.n) + (1-othrp$p.mx)*gamma(scale=th,shape),
where shape of the gamma distribution is chosen to ensure $E(G[i])=1$.
lmeNB,The functions to fit related models:
fitParaIND,
fitParaAR1,
fitSemiIND,
fitSemiAR1,
The subroutines of index.batch to compute the conditional probability index:
jCP.ar1,
CP1.ar1,
MCCP.ar1,
CP.ar1.se,
CP.se,
jCP,
## Not run:
# ## See the examples in help files of fitParaIND, fitParaAR1, fitSemiIND, fitSemiAR1 and lmeNB
#
# ## End(Not run)
Run the code above in your browser using DataLab